@@ -6,7 +6,7 @@
 # export WORKON_HOME="$(echo ${tmplocation}/WORKON_HOME.$$ | sed 's|//|/|g')"
 # export PROJECT_HOME="$(echo ${tmplocation}/PROJECT_HOME.$$ | sed 's|//|/|g')"
 
-export WORKON_HOME=$(mktemp -d -t "WORKON_HOME.$$")
-export PROJECT_HOME=$(mktemp -d -t "PROJECT_HOME.$$")
+export WORKON_HOME=$(mktemp -d -t "WORKON_HOME.XXXX.$$")
+export PROJECT_HOME=$(mktemp -d -t "PROJECT_HOME.XXXX.$$")
 
 #unset HOOK_VERBOSE_OPTION
