@@ -28,9 +28,7 @@ test_get_site_packages_dir () {
 test_lssitepackages () {
     mkvirtualenv "lssitepackagestest" >/dev/null 2>&1
     contents="$(lssitepackages)"    
-    actual=$(echo $contents | grep easy-install.pth)
-    expected=$(echo $contents)
-    assertSame "$expected" "$actual"
+    assertTrue "did not find easy_install in site-packages" "echo $contents | grep -q easy_install"
     deactivate
 }
 
@@ -46,14 +44,36 @@ test_lssitepackages_add2virtualenv () {
     deactivate
 }
 
-test_no_workon_home () {
+test_lssitepackages_no_workon_home () {
     old_home="$WORKON_HOME"
     export WORKON_HOME="$WORKON_HOME/not_there"
+    rm -rf "$WORKON_HOME"
     lssitepackages >"$old_home/output" 2>&1
     output=$(cat "$old_home/output")
     assertTrue "Did not see expected message" "echo $output | grep 'does not exist'"
     WORKON_HOME="$old_home"
 }
 
+test_lsvirtualenv_no_workon_home () {
+    old_home="$WORKON_HOME"
+    export WORKON_HOME="$WORKON_HOME/not_there"
+    rm -rf "$WORKON_HOME"
+    lsvirtualenv >"$old_home/output" 2>&1
+    output=$(cat "$old_home/output")
+    assertTrue "Did not see expected message" "echo $output | grep -q 'does not exist'"
+    WORKON_HOME="$old_home"
+}
+
+test_lsvirtualenv_space_in_workon_home () {
+    old_home="$WORKON_HOME"
+    export WORKON_HOME="$WORKON_HOME/with space"
+    mkdir "$WORKON_HOME"
+    (cd "$WORKON_HOME"; virtualenv testenv) 2>&1
+    lsvirtualenv -b >"$old_home/output"
+    output=$(cat "$old_home/output")
+    assertTrue "Did not see expected message in \"$output\"" "echo $output | grep -q 'testenv'"
+    WORKON_HOME="$old_home"
+}
+
 
 . "$test_dir/shunit2"
