@@ -18,7 +18,6 @@ oneTimeTearDown() {
 
 setUp () {
     echo
-    rm -f "$TMPDIR/catch_output"
 }
 
 test_with_project () {
@@ -40,15 +39,16 @@ test_without_project () {
 }
 
 test_space_in_path () {
-    old_project_home="$PROJECT_HOME"
+    (
+    set -e
     PROJECT_HOME="$PROJECT_HOME/with spaces"
     mkdir -p "$PROJECT_HOME"
     mkproject "myproject" >/dev/null 2>&1
-    cd $TMPDIR
+    cd "$WORKON_HOME"
     cdproject
-    assertSame "$PROJECT_HOME/myproject" "$(pwd)"
-    deactivate
-    PROJECT_HOME="$old_project_home"
+    [ "$PROJECT_HOME/myproject" == "$(pwd)" ]
+    )
+    assertTrue "Did not cd to project directory" $?
 }
 
 
