@@ -81,7 +81,15 @@ fi
 # Remember where we are running from.
 if [ -z "$VIRTUALENVWRAPPER_SCRIPT" ]
 then
-    export VIRTUALENVWRAPPER_SCRIPT="$0"
+    if [ -n "$BASH" ]
+    then
+        export VIRTUALENVWRAPPER_SCRIPT="$BASH_SOURCE"
+    elif [ -n "$ZSH_VERSION" ]
+    then
+        export VIRTUALENVWRAPPER_SCRIPT="$0"
+    else
+        export VIRTUALENVWRAPPER_SCRIPT="${.sh.file}"
+    fi
 fi
 
 # Portable shell scripting is hard, let's go shopping.
@@ -520,6 +528,10 @@ function rmvirtualenv {
             return 1
         fi
 
+        if [ ! -d "$env_dir" ]; then
+            echo "Did not find environment $env_dir to remove." >&2
+        fi
+
         # Move out of the current directory to one known to be
         # safe, in case we are inside the environment somewhere.
         typeset prior_dir="$(pwd)"
